==> wp-media-folder_6.1.5%2BAddons%28www.persianscript.ir%29.zip: wp-media-folder-addon/class/templates/settings_owncloud.php <==
<div class="content-wpmf-owncloud">
    <div id="config_owncloud" class="div_list wpmf_width_100">
        <div class="wpmf_width_100 ju-settings-option box-shadow-none m-b-0">
            <div class="odb-connector-form">
                <div class="wpmf_row_full" style="display: flex; margin: 0">
                    <input type="hidden" name="connect_owncloud" value="0">
                    <label class="ju-setting-label text" style="padding-left: 0"><?php esc_html_e('Connect ownCloud', 'wpmfAddon') ?></label>
                    <div class="ju-switch-button">
                        <label class="switch">
                            <input type="checkbox" name="connect_owncloud"
                                   value="1"
                                <?php
                                if (isset($connect_owncloud) && (int) $connect_owncloud === 1) {
                                    echo 'checked';
                                }
                                ?>
                            >
                            <span class="slider round"></span>
                        </label>
                    </div>
                </div>

                <h4><?php esc_html_e('Username', 'wpmfAddon') ?></h4>
                <div>
                    <input title name="OwnCloudUsername" type="text"
                           class="regular-text wpmf_width_100 p-lr-20"
                           value="<?php echo esc_attr($owncloud_config['username']) ?>">
                    <p class="description" id="tagline-description">
                        <?php esc_html_e('Insert your ownCloud username here.', 'wpmfAddon') ?>
                    </p>
                </div>
            </div>

            <div class="odb-connector-form">
                <h4><?php esc_html_e('Password', 'wpmfAddon') ?></h4>
                <div>
                    <input title name="OwnCloudPassword" type="password"
                           class="regular-text wpmf_width_100 p-lr-20"
                           value="<?php echo esc_attr($owncloud_config['password']) ?>">
                    <p class="description" id="tagline-description">
                        <?php esc_html_e('Insert your ownCloud password here.', 'wpmfAddon') ?>
                    </p>
                </div>
            </div>

            <div class="odb-connector-form">
                <h4><?php esc_html_e('ownCloud Url', 'wpmfAddon') ?></h4>
                <div>
                    <input title name="OwnCloudUrl" type="text"
                           class="regular-text wpmf_width_100 p-lr-20"
                           value="<?php echo esc_attr($owncloud_config['owncloudurl']) ?>">
                </div>
            </div>

            <?php
            //if (empty($owncloud_config['rootfoldername'])) :
            ?>
            <div class="odb-connector-form">
                <h4><?php esc_html_e('Root folder name', 'wpmfAddon') ?></h4>
                <div>
                    <input title name="RootFolderName" type="text"
                           class="regular-text wpmf_width_100 p-lr-20"
                           value="<?php echo esc_attr($owncloud_config['rootfoldername']) ?>">
                </div>
            </div>
            <?php //endif; ?>
            <a target="_blank" class="m-t-30 ju-button no-background orange-button waves-effect waves-light"
               href="https://www.joomunited.com/wordpress-documentation/wp-media-folder/710-wp-media-folder-addon-owncloud-integration">
                <?php esc_html_e('Read the online documentation', 'wpmfAddon') ?>
            </a>
        </div>
    </div>
    <button type="submit" name="btn_wpmf_save"
            class="btn_wpmf_save ju-button orange-button waves-effect waves-light" style="margin-top: 10px"><?php esc_html_e('Save Changes', 'wpmfAddon'); ?></button>
</div>

==> wp-media-folder-6.1.8%2BAddons%28www.persianscript.ir%29.zip: wp-media-folder-addon/class/templates/settings_owncloud.php <==
<div class="content-wpmf-owncloud">
    <div id="config_owncloud" class="div_list wpmf_width_100">
        <div class="wpmf_width_100 ju-settings-option box-shadow-none m-b-0">
            <div class="odb-connector-form">
                <div class="wpmf_row_full" style="display: flex; margin: 0">
                    <input type="hidden" name="connect_owncloud" value="0">
                    <label class="ju-setting-label text" style="padding-left: 0"><?php esc_html_e('Connect ownCloud', 'wpmfAddon') ?></label>
                    <div class="ju-switch-button">
                        <label class="switch">
                            <input type="checkbox" name="connect_owncloud"
                                   value="1"
                                <?php
                                if (isset($connect_owncloud) && (int) $connect_owncloud === 1) {
                                    echo 'checked';
                                }
                                ?>
                            >
                            <span class="slider round"></span>
                        </label>
                    </div>
                </div>

                <h4><?php esc_html_e('Username', 'wpmfAddon') ?></h4>
                <div>
                    <input title name="OwnCloudUsername" type="text"
                           class="regular-text wpmf_width_100 p-lr-20"
                           value="<?php echo esc_attr($owncloud_config['username']) ?>">
                    <p class="description" id="tagline-description">
                        <?php esc_html_e('Insert your ownCloud username here.', 'wpmfAddon') ?>
                    </p>
                </div>
            </div>

            <div class="odb-connector-form">
                <h4><?php esc_html_e('Password', 'wpmfAddon') ?></h4>
                <div>
                    <input title name="OwnCloudPassword" type="password"
                           class="regular-text wpmf_width_100 p-lr-20"
                           value="<?php echo esc_attr($owncloud_config['password']) ?>">
                    <p class="description" id="tagline-description">
                        <?php esc_html_e('Insert your ownCloud password here.', 'wpmfAddon') ?>
                    </p>
                </div>
            </div>

            <div class="odb-connector-form">
                <h4><?php esc_html_e('ownCloud Url', 'wpmfAddon') ?></h4>
                <div>
                    <input title name="OwnCloudUrl" type="text"
                           class="regular-text wpmf_width_100 p-lr-20"
                           value="<?php echo esc_attr($owncloud_config['owncloudurl']) ?>">
                </div>
            </div>

            <?php
            //if (empty($owncloud_config['rootfoldername'])) :
            ?>
            <div class="odb-connector-form">
                <h4><?php esc_html_e('Root folder name', 'wpmfAddon') ?></h4>
                <div>
                    <input title name="OwnCloudRootFolderName" type="text"
                           class="regular-text wpmf_width_100 p-lr-20"
                           value="<?php echo esc_attr($owncloud_config['rootfoldername']) ?>">
                </div>
            </div>
            <?php //endif; ?>
            <a target="_blank" class="m-t-30 ju-button no-background primary-button waves-effect waves-light"
               href="https://www.joomunited.com/wordpress-documentation/wp-media-folder/710-wp-media-folder-addon-owncloud-integration">
                <?php esc_html_e('Read the online documentation', 'wpmfAddon') ?>
            </a>
        </div>
    </div>
    <button type="submit" name="btn_wpmf_save"
            class="btn_wpmf_save ju-button orange-button waves-effect waves-light" style="margin-top: 10px"><?php esc_html_e('Save Changes', 'wpmfAddon'); ?></button>
</div>
